/*-
# MS WINDOWS-BASED RUBIK'S CUBE(tm)
#
#  wrubik.h
#
###
#
#  Copyright (c) 1996 - 2006	David Albert Bagley, bagleyd@tux.org
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "useful",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Header file for wrubik.c */

#define IDM_GET		100
#define IDM_WRITE	101
#define IDM_EXIT	102
#define IDM_HIDE	103
#define IDM_UNDO	200
#define IDM_REDO	201
#define IDM_CLEAR	202
#define IDM_RANDOMIZE	203
#define IDM_PRACTICE	204
#define IDM_SOLVE	205
#define IDM_ORIENTIZE	206
#define IDM_DIM		207
#define IDM_TOP		300
#define IDM_RIGHT	301
#define IDM_BOTTOM	302
#define IDM_LEFT	303
#define IDM_CW		305
#define IDM_CCW		307
#define IDM_TR		308
#define IDM_BR		309
#define IDM_BL		310
#define IDM_TL		311
#define IDM_CONTROL_TOP	340
#define IDM_CONTROL_RIGHT	341
#define IDM_CONTROL_BOTTOM	342
#define IDM_CONTROL_LEFT	343
#define IDM_CONTROL_CW	345
#define IDM_CONTROL_CCW	347
#define IDM_CONTROL_TR	348
#define IDM_CONTROL_BR	349
#define IDM_CONTROL_BL	350
#define IDM_CONTROL_TL	351
#define IDM_DEC		400
#define IDM_INC		401
#define IDM_DECX	402
#define IDM_INCX	403
#define IDM_DECY	404
#define IDM_INCY	405
#define IDM_DECZ	406
#define IDM_INCZ	407
#define IDM_ABOUT	500
#define IDM_DESCRIPTION	501
#define IDM_FEATURES	502
#define IDM_REFERENCES	503
